@@ -11,7 +11,7 @@ use Moo;
 use File::ShareDir::ProjectDistDir;
 use Unicode::CaseFold;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 has dict => ( is => q(rw), default => sub { {}; }, );
 has language  => ( is => q(rw) );
@@ -22,7 +22,9 @@ sub BUILD {
     my $self = shift;
     my $args = shift;
 
-    my $share_dir = dist_dir(__PACKAGE__);
+    my $pkg = __PACKAGE__;
+    $pkg =~ s{::}{-}g;
+    my $share_dir = dist_dir($pkg);
     my @dict_file;
     find( sub { push @dict_file, $File::Find::name if -e }, $share_dir, );
 
@@ -145,7 +147,7 @@ Text::UnAbbrev - Expand abbreviations and acronyms.
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
